{ config, inputs, lib, pkgs, ... }:
let

in
{
  imports = [
    ../default.nix
    #"${inputs.mobile-nixos}/modules/quirks/qualcomm/sdm845-modem.nix"
    #"${inputs.mobile-nixos}/modules/quirks/audio.nix"
    ];

  stitchyconf.form = "handheld";

  mobile = {
    beautification = {
      silentBoot = lib.mkDefault true;
      splash = lib.mkDefault true;
    };
    boot.stage-1 = {
      kernel.useStrictKernelConfig = true;
      networking.enable = true;
    };
    quirks = {
      audio.alsa-ucm-meld = true;
      qualcomm.sdm845-modem.enable = true;
    };
  };

  boot.loader = {
    efi.canTouchEfiVariables = false;
    systemd-boot.enable = false;
  };
  #services.openssh.enable = true;
  services.xserver.desktopManager.phosh = {
    enable = true;
    user = "stitchynyan";
    group = "users";
  };

  #services.xserver.desktopManager.plasma5 = {
  # enable = true;
  # mobile.enable = true;
  #};

  programs.firefox.enable = true;
  programs.calls.enable = true;

  hardware = { 
    bluetooth.enable = true;
    pulseaudio.enable = lib.mkForce false;
    sensor.iio.enable = true;
  };
  
  networking.networkmanager = {
    enable = true;
    unmanaged = [ "rndis0" "usb0" ];
  };

  /*services.pipewire.wireplumber.configPackages = [
    (pkgs.writeTextDir "share/wireplumber/quailcum.lua.d/51-qcom-sdm845.lua" ''
      ${builtins.readFile (pkgs.fetchurl {
      url = "https://gitlab.com/postmarketOS/pmaports/-/raw/0aa9524204e9c9c002c860b87c972bc2ebf025f3/device/community/soc-qcom-sdm845/51-qcom-sdm845.lua";
      hash = "sha256-56oNJJyuZZe1Iig1xskDuyazw3PbRZtmU/YRFUTqjwk=";
      })}
      '')
    ];*/

  services.pipewire.wireplumber.configPackages = [
    (pkgs.writeTextDir "share/wireplumber/wireplumber.conf.d/51-qcom-sdm845.conf" ''
      monitor.alsa.rules = [
        {
          matches = [
            {
              node.name = "~alsa_output.*"
            }
          ]
          actions = {
            update-props = {
              audio.format           = "S16LE"
              audio.rate             = 48000
              api.alsa.period-size   = 4096
              api.alsa.period-num    = 6
              api.alsa.headroom      = 512
            }
          }
        }
      ]
    '')
  ];

  services.openssh = {
    enable = true;
    settings.PasswordAuthentication = true;
  };

  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "oneplus-sdm845-firmware"
    "oneplus-sdm845-firmware-xz"
  ];
  system.stateVersion = "23.11";
}
